@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import re
+import typing
 import warnings
 from decimal import Decimal
 from typing import (
@@ -905,7 +906,7 @@ class StrawberryPlugin(Plugin):
 
         return None
 
-    def get_type_analyze_hook(self, fullname: str):
+    def get_type_analyze_hook(self, fullname: str) -> Union[Callable[..., Type], None]:
         if self._is_strawberry_lazy_type(fullname):
             return lazy_type_analyze_callback
 
@@ -1030,14 +1031,15 @@ class StrawberryPlugin(Plugin):
         )
 
 
-def plugin(version: str):
+def plugin(version: str) -> typing.Type[StrawberryPlugin]:
     match = VERSION_RE.match(version)
     if match:
         MypyVersion.VERSION = Decimal(".".join(match.groups()))
     else:
         MypyVersion.VERSION = FALLBACK_VERSION
         warnings.warn(
-            f"Mypy version {version} could not be parsed. Reverting to v0.800"
+            f"Mypy version {version} could not be parsed. Reverting to v0.800",
+            stacklevel=1,
         )
 
     return StrawberryPlugin
